@@ -53,6 +53,10 @@
 #' your input data meet the requirements, the checks are unnecessary and can be
 #' turned off to improve performance.
 #'
+#' @param message Should informational messages (those messages that are
+#' neither warnings nor errors) be printed when constructing the network?
+#' Defaults to \code{TRUE}.
+#'
 #' @param ... Arguments passed on to \code{\link[sf]{st_as_sf}}, if nodes need
 #' to be converted into an \code{\link[sf]{sf}} object during construction.
 #'
@@ -102,7 +106,7 @@
 #' @export
 sfnetwork = function(nodes, edges = NULL, directed = TRUE, node_key = "name",
                      edges_as_lines = NULL, length_as_weight = FALSE,
-                     force = FALSE, ...) {
+                     force = FALSE, message = TRUE, ...) {
   # Prepare nodes.
   # If nodes is not an sf object:
   # --> Try to convert it to an sf object.
@@ -140,12 +144,12 @@ sfnetwork = function(nodes, edges = NULL, directed = TRUE, node_key = "name",
   # --> Adding additional attributes if requested.
   if (is.null(edges)) {
     # Run validity check for nodes only and return the network.
-    if (! force) require_valid_network_structure(x_sfn, message = TRUE)
+    if (! force) require_valid_network_structure(x_sfn, message = message)
     return (x_sfn)
   }
   if (edges_as_lines) {
     # Run validity check before explicitizing edges.
-    if (! force) require_valid_network_structure(x_sfn, message = TRUE)
+    if (! force) require_valid_network_structure(x_sfn, message = message)
     # Add edge geometries if needed.
     if (edges_are_explicit) {
       # Edges already have geometries, we don't need to add them.
@@ -163,7 +167,7 @@ sfnetwork = function(nodes, edges = NULL, directed = TRUE, node_key = "name",
       x_sfn = implicitize_edges(x_sfn)
     }
     # Run validity check after implicitizing edges.
-    if (! force) require_valid_network_structure(x_sfn, message = TRUE)
+    if (! force) require_valid_network_structure(x_sfn, message = message)
   }
   if (length_as_weight) {
     edges = edges_as_sf(x_sfn)
@@ -289,14 +293,13 @@ as_sfnetwork.sf = function(x, ...) {
 #' @name as_sfnetwork
 #' @examples
 #' # From a linnet object.
-#' if (require(spatstat, quietly = TRUE)) {
+#' if (require(spatstat.geom, quietly = TRUE)) {
 #'   as_sfnetwork(simplenet)
 #' }
 #'
 #' @export
 as_sfnetwork.linnet = function(x, ...) {
   check_spatstat("spatstat.geom")
-
   # The easiest approach is the same as for psp objects, i.e. converting the
   # linnet object into a psp format and then applying the corresponding method.
   x_psp = spatstat.geom::as.psp(x)
@@ -313,17 +316,9 @@ as_sfnetwork.linnet = function(x, ...) {
 #' }
 #'
 #' @importFrom sf st_as_sf st_collection_extract
-#' @importFrom utils packageVersion
 #' @export
 as_sfnetwork.psp = function(x, ...) {
-  # Add an extra check to test the version of sf package. See:
-  # https://github.com/luukvdmeer/sfnetworks/pull/138#issuecomment-803430686
-  if (packageVersion("sf") < "0.9.8") {
-    stop(
-      "spatstat code requires sf >= 0.9.8; please update sf",
-      call. = FALSE
-    )
-  }
+  check_spatstat_sf()
   # The easiest method for transforming a Line Segment Pattern (psp) object
   # into sfnetwork format is to transform it into sf format and then apply
   # the usual methods.
