@@ -15,7 +15,7 @@ check_spatstat = function(pkg) {
     )
   } else {
     spst_ver = try(packageVersion("spatstat"), silent = TRUE)
-    if (!inherits(spst_ver, "try-error") && spst_ver < 2.0-0) {
+    if (!inherits(spst_ver, "try-error") && spst_ver < "2.0-0") {
       stop(
         "You have an old version of spatstat which is incompatible with ",
         pkg,
